.cf:before,
.cf:after {
    content: " "; /* 1 */
    display: table; /* 2 */
}

.cf:after {
    clear: both;
}

/**
 * For IE 6/7 only
 * Include this rule to trigger hasLayout and contain floats.
 */
.cf {
    *zoom: 1;
}

/*****************************************************************************/

body {
    background: #879DCC url(../images/square_bg.png);
}

body, select, input, button {
    font: 14px/21px 'Open Sans', 'Lucida Grande', Tahoma, sans-serif;
    color: #132D63;
}

a {
    color: inherit;
}

input[type=submit], input[type=button], button {
    border: 0;
    background-color: #E4C848;
    color: #944F18;
    font-weight: bold;
}

input[type=submit]:disabled, input[type=button]:disabled, button:disabled {
    color: #AB9B53;
}

h1 {
    line-height: 49px;
    margin: 0;
}

h2 {
    line-height: 42px;
    margin: 0;
}

p {
    margin: 0 0 21px 0;
}

button a {
    text-decoration: none;
    color: inherit;
}

#wrapper {
    padding: 20px;
    border: 5px solid #132D63;
    background-color: white;
    width: 720px;
    margin: 20px auto;
    position: relative;
}

.logout {
    position: absolute;
    right: 20px;
    top: 20px;
    line-height: 49px;
}

#about {
    width: 50%;
}

#friendlist {
    font-size: 2em;
}

.lists > .list {
    width: 300px;
    float: left;
}

.list select {
    width: 100%;
    height: 600px;
}

.actions {
    width: 120px;
    float: left;
    padding-top: 42px;
}

.actions button {
    display: block;
    width: 80px;
    margin: 20px;
    font-size: 28px;
    line-height: 42px;
}