{% extends "base.html" %}

{% block content %}
<p id="about">
    Facebook's friendlist management isn't the best. This small app tries to
    ease that pain. After logging in, you select a friendlist to edit. It'll
    show two columns: unlisted and listed. You can move friends from and to
    lists by clicking on the buttons between them. Once you're done, click
    "Save changes".
</p>
<p>
    <button><a href="/login">Login with Facebook</a></button>
</p>
{% endblock %}