<!doctype html>
<html>
    <head>
        <title>Friendlists</title>
        <link rel="stylesheet" href="http://fonts.googleapis.com/css?family=Open+Sans:400,700">
        <link rel="stylesheet" href="/static/css/normalize.css">
        <link rel="stylesheet" href="/static/css/styles.css">
        <script src="//cdnjs.cloudflare.com/ajax/libs/jquery/1.8.3/jquery.min.js"></script>
        {% block js %}{% endblock %}
    </head>
    <body>
    <div id="wrapper">
        <h1>Friendlists</h1>
        {% block content %}{% endblock %}
    </div>
    </body>
</html>